@@ -27,8 +27,8 @@ from ..aws_operations import (
     ses_send_email,
 )
 from ..custom_types import (
-    Clients,
-    Config,
+    AuthClients,
+    AuthConfig,
     CustomError,
     HttpError,
     HttpSuccess,
@@ -54,11 +54,11 @@ LOG: logging.Logger = logging.getLogger(__name__)
 
 class Auth:
 
-    default_algorithm = "ES256"
-    default_boto3_config = Boto3Config(
+    default_algorithm: str = "ES256"
+    default_boto3_config: Boto3Config = Boto3Config(
         connect_timeout=5, read_timeout=5, region_name="eu-west-1"
     )
-    clients = Clients(
+    clients: AuthClients = AuthClients(
         s3_client=boto3.client("s3", config=default_boto3_config),
         s3_resource=boto3.resource("s3", config=default_boto3_config),
         sqs_client=boto3.client(
@@ -71,12 +71,15 @@ class Auth:
         ses_client=boto3.client("ses", config=default_boto3_config),
         athena_client=boto3.client("athena", config=default_boto3_config),
     )
+    config: AuthConfig = None
+    boto3_config: Boto3Config = None
+    router: APIRouter = None
 
-    def __init__(self, config: Config, boto3_config=default_boto3_config):
+    def __init__(self, config: AuthConfig, boto3_config=default_boto3_config):
 
-        self.config = config
+        self.config: AuthConfig = config
         self.boto3_config = boto3_config
-        self.router = APIRouter()
+        self.router = APIRouter(prefix="/api/v1/auth", tags=["auth"])
         self.router.add_api_route(
             path="/magic-link",
             endpoint=self.send_magic_link,
@@ -509,6 +512,29 @@ class Auth:
             )
         return http_response
 
+    def verify_email_domain(self, email_address: EmailStr) -> Union[bool, CustomError]:
+        try:
+            email_domain = email_address.split("@")[-1]
+            allowed_email_domains = self.config.allowed_email_domains
+            if email_domain in allowed_email_domains:
+                return True
+            else:
+                LOG.error(
+                    f"Email domain is not allowed for the email address: {email_address}"
+                )
+                return CustomError(
+                    f"Email domain is not allowed for the email address: {email_address}",
+                    [f"{ex}"],
+                )
+        except Exception as ex:
+            LOG.error(
+                f"Email domain is not allowed for the email address: {email_address}"
+            )
+            return CustomError(
+                f"Email domain is not allowed for the email address: {email_address}",
+                [f"{ex}"],
+            )
+
     # @router.post("/login", response_model=HttpSuccess)
     async def login(self, login_hash: LoginHash) -> JSONResponse:
         try:
@@ -554,6 +580,16 @@ class Auth:
                     message=jwt_token_maybe.message, reasons=jwt_token_maybe.reasons
                 )
 
+            verified_email_domain = self.verify_email_domain(jwt_param.email)
+            if isinstance(verified_email_domain, CustomError):
+                LOG.error(
+                    f"Message: {verified_email_domain.message}. Reasons: {verified_email_domain.reasons}"
+                )
+                return http_403_json(
+                    message=verified_email_domain.message,
+                    reasons=verified_email_domain.reasons,
+                )
+
             http_response = http_200_json(HttpSuccess(ok="ok"))
             max_age = self.config.cookie_max_age_days * 24 * 60 * 60
             cookie_domain = Auth.get_cookie_domain_from_cors(
